summaryrefslogtreecommitdiffstats
path: root/src/formula.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/formula.cpp')
-rw-r--r--src/formula.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/formula.cpp b/src/formula.cpp
index 64555c9..01a96b3 100644
--- a/src/formula.cpp
+++ b/src/formula.cpp
@@ -151,13 +151,13 @@ void FormulaList::generateBitmaps(const char *path)
return;
}
Portable::sysTimerStop();
// run ps2epsi to convert to an encapsulated postscript file with
// boundingbox (dvips with -E has some problems here).
sprintf(psArgs,"%s_tmp.ps %s.eps",formBase.data(),formBase.data());
Portable::sysTimerStart();
- if (Portable::system("ps2epsi",psArgs)!=0)
+ if (Portable::system("eps2eps",psArgs)!=0)
{
- err("Problems running ps2epsi. Check your installation!\n");
+ err("Problems running eps2eps. Check your installation!\n");
Portable::sysTimerStop();
QDir::setCurrent(oldDir);
return;
@@ -151,13 +151,13 @@ void FormulaList::generateBitmaps(const char *path)
}
Portable::sysTimerStop();
- // run ps2epsi to convert to an encapsulated postscript file with
+ // run eps2eps to convert to an encapsulated postscript file with
// boundingbox (dvips with -E has some problems here).
sprintf(psArgs,"%s_tmp.ps %s.eps",formBase.data(),formBase.data());